@@ -8,8 +8,10 @@
 #
 
 from io import BytesIO
+from pathlib import Path
+
+from xlsxwriter.workbook import Workbook
 
-from ...workbook import Workbook
 from ..excel_comparison_test import ExcelComparisonTest
 
 
@@ -50,3 +52,16 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook.close()
 
         self.assertExcelEqual()
+
+    def test_create_file_with_path(self):
+        """Test the creation of an XlsxWriter file with a background image."""
+
+        workbook = Workbook(self.got_filename)
+
+        worksheet = workbook.add_worksheet()
+
+        worksheet.set_background(Path(self.image_dir + "logo.jpg"))
+
+        workbook.close()
+
+        self.assertExcelEqual()
