@@ -3,11 +3,13 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
+from xlsxwriter.workbook import Workbook
+
 from ..excel_comparison_test import ExcelComparisonTest
-from ...workbook import Workbook
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +19,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('format01.xlsx')
+        self.set_filename("format01.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with unused formats."""
@@ -26,20 +27,20 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet1 = workbook.add_worksheet()
-        worksheet2 = workbook.add_worksheet('Data Sheet')
+        worksheet2 = workbook.add_worksheet("Data Sheet")
         worksheet3 = workbook.add_worksheet()
 
-        unused1 = workbook.add_format({'bold': 1})
-        bold = workbook.add_format({'bold': 1})
-        unused2 = workbook.add_format({'bold': 1})
-        unused3 = workbook.add_format({'italic': 1})
+        unused1 = workbook.add_format({"bold": 1})
+        bold = workbook.add_format({"bold": 1})
+        unused2 = workbook.add_format({"bold": 1})
+        unused3 = workbook.add_format({"italic": 1})
 
-        worksheet1.write('A1', 'Foo')
-        worksheet1.write('A2', 123)
+        worksheet1.write("A1", "Foo")
+        worksheet1.write("A2", 123)
 
-        worksheet3.write('B2', 'Foo')
-        worksheet3.write('B3', 'Bar', bold)
-        worksheet3.write('C4', 234)
+        worksheet3.write("B2", "Foo")
+        worksheet3.write("B3", "Bar", bold)
+        worksheet3.write("C4", 234)
 
         workbook.close()
 
