@@ -3,11 +3,13 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
+from xlsxwriter.workbook import Workbook
+
 from ..excel_comparison_test import ExcelComparisonTest
-from ...workbook import Workbook
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,11 +19,12 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
+        self.set_filename("header_image10.xlsx")
 
-        self.set_filename('header_image10.xlsx')
-
-        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup'],
-                                'xl/worksheets/sheet2.xml': ['<pageMargins', '<pageSetup']}
+        self.ignore_elements = {
+            "xl/worksheets/sheet1.xml": ["<pageMargins", "<pageSetup"],
+            "xl/worksheets/sheet2.xml": ["<pageMargins", "<pageSetup"],
+        }
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with image(s)."""
@@ -31,13 +34,12 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         worksheet1 = workbook.add_worksheet()
         worksheet2 = workbook.add_worksheet()
 
-        worksheet1.set_header('&L&G',
-                              {'image_left': self.image_dir + 'red.jpg'})
+        worksheet1.set_header("&L&G", {"image_left": self.image_dir + "red.jpg"})
 
-        worksheet2.write('A1', 'Foo')
-        worksheet2.write_comment('B2', 'Some text')
+        worksheet2.write("A1", "Foo")
+        worksheet2.write_comment("B2", "Some text")
 
-        worksheet2.set_comments_author('John')
+        worksheet2.set_comments_author("John")
 
         workbook.close()
 
