@@ -8,7 +8,8 @@
 #
 import warnings
 
-from ...workbook import Workbook
+from xlsxwriter.workbook import Workbook
+
 from ..excel_comparison_test import ExcelComparisonTest
 
 
