@@ -18,16 +18,21 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-        self.set_filename("utf8_11.xlsx")
+        self.set_filename("utf8_06.xlsx")
 
     def test_create_file(self):
         """Test the creation of an XlsxWriter file with utf-8 strings."""
 
-        workbook = Workbook(self.got_filename, {"strings_to_urls": True})
+        workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.write("A1", "１２３４５")
+        bold = workbook.add_format({"bold": 1})
+        italic = workbook.add_format({"italic": 1})
+
+        worksheet.write("A1", "Foo", bold)
+        worksheet.write("A2", "Bar", italic)
+        worksheet.write_rich_string("A3", "Caf", bold, "é")
 
         workbook.close()
 
