@@ -10,8 +10,9 @@
 import unittest
 from io import StringIO
 
-from ...comments import CommentType
-from ...vml import Vml
+from xlsxwriter.comments import CommentType
+from xlsxwriter.vml import Vml
+
 from ..helperfunctions import _vml_to_list, _xml_to_list
 
 
