@@ -11,7 +11,8 @@ import unittest
 from datetime import date, time
 from io import StringIO
 
-from ...worksheet import Worksheet
+from xlsxwriter.worksheet import Worksheet
+
 from ..helperfunctions import _xml_to_list
 
 
